@@ -29,20 +29,19 @@
 #include <string.h>
 #include <stdio.h>
 #include <errno.h>
+#include <sys/types.h>
+
 #include <glib.h>
 #include <dbus/dbus.h>
 
 #include <bluetooth/bluetooth.h>
 
-#include <openobex/obex.h>
-#include <openobex/obex_const.h>
-
 #include "plugin.h"
 #include "obex.h"
 #include "service.h"
 #include "mimetype.h"
 #include "log.h"
-#include "dbus.h"
+#include "manager.h"
 #include "btio.h"
 #include "obexd.h"
 #include "gdbus.h"
@@ -219,17 +218,24 @@ static void *synce_connect(struct obex_session *os, int *err)
 {
 	DBusConnection *conn;
 	struct synce_context *context;
+	char *address;
 
 	manager_register_session(os);
 
-	conn = obex_dbus_get_connection();
+	conn = manager_dbus_get_connection();
 	if (!conn)
 		goto failed;
 
 	context = g_new0(struct synce_context, 1);
 	context->dbus_conn = conn;
 	context->lasterr = -EAGAIN;
-	context->id = obex_get_id(os);
+	context->os = os;
+
+	if (obex_getpeername(os, &address) == 0) {
+		context->id = g_strdup_printf("%s+%d", address,
+							SYNCEVOLUTION_CHANNEL);
+		g_free(address);
+	}
 
 	if (err)
 		*err = 0;
@@ -243,18 +249,13 @@ failed:
 	return NULL;
 }
 
-static int synce_put(struct obex_session *os, obex_object_t *obj,
-					void *user_data)
+static int synce_put(struct obex_session *os, void *user_data)
 {
 	return 0;
 }
 
-static int synce_get(struct obex_session *os, obex_object_t *obj,
-					gboolean *stream, void *user_data)
+static int synce_get(struct obex_session *os, void *user_data)
 {
-	if (stream)
-		*stream = TRUE;
-
 	return obex_get_stream_start(os, NULL);
 }
 
@@ -284,8 +285,10 @@ static void synce_disconnect(struct obex_session *os, void *user_data)
 static void *synce_open(const char *name, int oflag, mode_t mode,
 				void *user_data, size_t *size, int *err)
 {
+	struct synce_context *context = user_data;
+
 	if (err)
-		*err = 0;
+		*err = context ? 0 : -EFAULT;
 
 	return user_data;
 }
@@ -331,8 +334,7 @@ done:
 	return 0;
 }
 
-static ssize_t synce_read(void *object, void *buf, size_t count,
-					uint8_t *hi, unsigned int *flags)
+static ssize_t synce_read(void *object, void *buf, size_t count)
 {
 	struct synce_context *context = object;
 	DBusConnection *conn;
@@ -343,22 +345,17 @@ static ssize_t synce_read(void *object, void *buf, size_t count,
 	gboolean authenticate;
 	DBusPendingCall *call;
 
-	if (flags)
-		*flags = 0;
-
-	if (context->buffer) {
-		*hi = OBEX_HDR_BODY;
+	if (context->buffer)
 		return string_read(context->buffer, buf, count);
-	}
 
-	conn = obex_dbus_get_connection();
+	conn = manager_dbus_get_connection();
 	if (conn == NULL)
-		goto failed;
+		return -EPERM;
 
 	msg = dbus_message_new_method_call(SYNCE_BUS_NAME, SYNCE_PATH,
 				SYNCE_SERVER_INTERFACE, "Connect");
 	if (!msg)
-		goto failed;
+		return -EPERM;
 
 	dbus_message_iter_init_append(msg, &iter);
 	dbus_message_iter_open_container(&iter, DBUS_TYPE_ARRAY,
@@ -368,8 +365,7 @@ static ssize_t synce_read(void *object, void *buf, size_t count,
 
 	append_dict_entry(&dict, "id", DBUS_TYPE_STRING, context->id);
 
-	snprintf(transport, sizeof(transport), "%s.obexd",
-					OPENOBEX_SERVICE);
+	snprintf(transport, sizeof(transport), "%s.obexd", OBEXD_SERVICE);
 	append_dict_entry(&dict, "transport", DBUS_TYPE_STRING, transport);
 
 	snprintf(transport_description, sizeof(transport_description),
@@ -387,7 +383,7 @@ static ssize_t synce_read(void *object, void *buf, size_t count,
 	if (!dbus_connection_send_with_reply(conn, msg, &call, -1)) {
 		error("D-Bus call to %s failed.", SYNCE_SERVER_INTERFACE);
 		dbus_message_unref(msg);
-		goto failed;
+		return -EPERM;
 	}
 
 	dbus_pending_call_set_notify(call, connect_cb, context, NULL);
@@ -396,9 +392,6 @@ static ssize_t synce_read(void *object, void *buf, size_t count,
 	dbus_message_unref(msg);
 
 	return -EAGAIN;
-
-failed:
-	return -EPERM;
 }
 
 static ssize_t synce_write(void *object, const void *buf, size_t count)
@@ -459,6 +452,7 @@ static struct obex_service_driver synce = {
 	.name = "OBEX server for SyncML, using SyncEvolution",
 	.service = OBEX_SYNCEVOLUTION,
 	.channel = SYNCEVOLUTION_CHANNEL,
+	.secure = TRUE,
 	.record = SYNCEVOLUTION_RECORD,
 	.target = SYNCML_TARGET,
 	.target_size = SYNCML_TARGET_SIZE,
